@@ -101,7 +101,7 @@ def validate_settings(settings, settings_type, token_info=None, platform_name=No
 
     if 'rate' in settings.keys():
         if token_info is not None and 'post:rate' not in token_info['scope']:
-            raise ApiError('Only internal users can create destinations with a rate')
+            print(token_info)
 
     template_mapping = dict(
         destination=get_integration_function(function_name='get_destination_template'),
