@@ -193,7 +193,7 @@ def create_parallel_chunks(job_uuid, bucket_name, file_pattern, platform_name, d
         if 0 < chunk_size <= chunk_records:
             push_chunks_to_distribute(
                 chunk_pointer=chunk_pointer, chunk_multiplier=chunk_multiplier, chunk_path=chunk_path,
-                bucket_name=bucket_name, platform_name=platform_name,
+                platform_name=platform_name,
                 job_uuid=job_uuid, segments=segments, destination=destination,
                 file_headers=file_headers, id_types=id_types, operations=operations,
                 chunk_number=chunk_number, start_time=start_time
@@ -209,7 +209,7 @@ def create_parallel_chunks(job_uuid, bucket_name, file_pattern, platform_name, d
             chunk_records / (chunk_size / chunk_multiplier))
         push_chunks_to_distribute(
             chunk_pointer=chunk_pointer, chunk_multiplier=chunk_multiplier, chunk_path=chunk_path,
-            bucket_name=bucket_name, platform_name=platform_name,
+            platform_name=platform_name,
             job_uuid=job_uuid, segments=segments, destination=destination,
             file_headers=file_headers, id_types=id_types, operations=operations,
             chunk_number=chunk_number, start_time=start_time
@@ -220,15 +220,17 @@ def create_parallel_chunks(job_uuid, bucket_name, file_pattern, platform_name, d
     return dict(job_uuid=job_uuid, total_chunks=total_chunks)
 
 
-def push_chunks_to_distribute(chunk_pointer, chunk_path, job_uuid, bucket_name,
+def push_chunks_to_distribute(chunk_pointer, chunk_path, job_uuid,
                               platform_name, start_time,
                               destination, file_headers, segments, id_types, operations, chunk_number, **kwargs):
     from stratus_api.integrations.tasks.distributions import deliver_data_task
     from stratus_api.storage.gcs import upload_file_to_gcs
+    from stratus_api.core.settings import get_settings
     import os
     from datetime import datetime
     now = datetime.utcnow()
     chunk_pointer.close()
+    bucket_name = get_settings()['bucket_name']
     file_path = CHUNKED_FILE_GCS_PATH_FORMAT.format(
         job_uuid=job_uuid,
         chunk_number=chunk_number,
@@ -237,8 +239,9 @@ def push_chunks_to_distribute(chunk_pointer, chunk_path, job_uuid, bucket_name,
         day=now.day,
         hour=now.hour,
         minute=now.minute)
-    upload_file_to_gcs(local_path=chunk_path, file_path=file_path)
-    deliver_data_task.delay(bucket_name=bucket_name, platform_name=platform_name, file_pattern=file_path,
+    upload_file_to_gcs(local_path=chunk_path, file_path=file_path, bucket_name=bucket_name)
+    deliver_data_task.delay(bucket_name=bucket_name, platform_name=platform_name,
+                            file_pattern=file_path,
                             start_time=start_time.timestamp(),
                             job_uuid=job_uuid, segments=segments, destination=destination, file_headers=file_headers,
                             id_types=id_types, operations=operations, chunk_start_number=chunk_number)
