@@ -5,7 +5,8 @@ def create_segment_request(user, token_info, body):
         external_id, external_attributes = create_entity(
             entity_type='segment', settings=body['settings'],
             name=body['name'], platform_name=body['platform_name'],
-            destination=body['destination'], segment_uuid=body['segment_uuid']
+            destination=body['destination'], segment_uuid=body['segment_uuid'],
+            token_info=token_info
         )
     except ApiError as e:
         return dict(status=400, title='Bad Request', detail=e.args[0], type='about:blank'), 400
